==> unruled_api-fabric%2B1.21.3-1.4.1-sources.jar: mc/recraftors/unruled_api/mixin/ServerWorldMixin.java <==
package mc.recraftors.unruled_api.mixin;

import com.llamalad7.mixinextras.injector.wrapoperation.Operation;
import com.llamalad7.mixinextras.injector.wrapoperation.WrapOperation;
import mc.recraftors.unruled_api.rules.OverridesManager;
import mc.recraftors.unruled_api.utils.IGameruleOverridesProvider;
import net.minecraft.class_1928;
import net.minecraft.class_1937;
import net.minecraft.class_26;
import net.minecraft.class_2874;
import net.minecraft.class_32;
import net.minecraft.class_3218;
import net.minecraft.class_3949;
import net.minecraft.class_5268;
import net.minecraft.class_5269;
import net.minecraft.class_5304;
import net.minecraft.class_5321;
import net.minecraft.class_5363;
import net.minecraft.class_5455;
import net.minecraft.class_6880;
import net.minecraft.class_8565;
import net.minecraft.server.MinecraftServer;
import org.spongepowered.asm.mixin.*;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;

import java.util.List;
import java.util.concurrent.Executor;

@Mixin(class_3218.class)
public abstract class ServerWorldMixin extends class_1937 implements IGameruleOverridesProvider {

    protected ServerWorldMixin(class_5269 properties, class_5321<class_1937> registryRef, class_5455 registryManager, class_6880<class_2874> dimensionEntry, boolean isClient, boolean debugWorld, long seed, int maxChainedNeighborUpdates) {
        super(properties, registryRef, registryManager, dimensionEntry, isClient, debugWorld, seed, maxChainedNeighborUpdates);
    }

    @Shadow public abstract class_26 getPersistentStateManager();

    @Shadow
    public abstract class_1928 getGameRules();

    @Unique private OverridesManager gamerulesOverrides;

    @SuppressWarnings("brittleShift")
    @Inject(
            method = "<init>",
            at = @At(
                    value = "INVOKE",
                    target = "Lnet/minecraft/world/PersistentStateManager;getOrCreate(Lnet/minecraft/world/PersistentState$Type;Ljava/lang/String;)Lnet/minecraft/world/PersistentState;",
                    shift = At.Shift.AFTER
            )
    )
    private void unruled_initGamerulesOverridesManager(
            MinecraftServer server, Executor workerExecutor, class_32.class_5143 session,
            class_5268 properties, class_5321<class_1937> worldKey, class_5363 dimensionOptions,
            class_3949 worldGenerationProgressListener, boolean debugWorld, long seed,
            List<class_5304> spawners, boolean shouldTickTime, class_8565 random, CallbackInfo ci
    ) {
        server.method_27728().method_45560();
        class_1928 rules = properties.method_146();
        this.gamerulesOverrides = this.getPersistentStateManager().method_17924(
                OverridesManager.getPersistentStateType(rules, server.method_27728().method_45560()), "gamerules"
        );
    }

    @Inject(method="getGameRules", at = @At("HEAD"), cancellable = true)
    private void unruled_getGameRulesOverrides(CallbackInfoReturnable<class_1928> cir) {
        cir.setReturnValue(this.gamerulesOverrides.getOverrides());
    }

    @Override
    public OverridesManager unruled_getOverridesManager() {
        return this.gamerulesOverrides;
    }

    @WrapOperation(method = "tickTime", at = @At(value = "INVOKE", target = "Lnet/minecraft/world/level/ServerWorldProperties;getGameRules()Lnet/minecraft/world/GameRules;"))
    private class_1928 unruled_allowDaylightCycleOverride(class_5268 instance, Operation<class_1928> original) {
        return this.getGameRules();
    }
}

==> unruled_api-fabric%2B1.21.5-1.4-sources.jar: mc/recraftors/unruled_api/mixin/ServerWorldMixin.java <==
package mc.recraftors.unruled_api.mixin;

import mc.recraftors.unruled_api.rules.OverridesManager;
import mc.recraftors.unruled_api.utils.IGameruleOverridesProvider;
import net.minecraft.class_1928;
import net.minecraft.class_1937;
import net.minecraft.class_26;
import net.minecraft.class_2874;
import net.minecraft.class_32;
import net.minecraft.class_3218;
import net.minecraft.class_3949;
import net.minecraft.class_5268;
import net.minecraft.class_5269;
import net.minecraft.class_5304;
import net.minecraft.class_5321;
import net.minecraft.class_5363;
import net.minecraft.class_5455;
import net.minecraft.class_6880;
import net.minecraft.class_8565;
import net.minecraft.server.MinecraftServer;
import org.spongepowered.asm.mixin.*;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;

import java.util.List;
import java.util.concurrent.Executor;

@Mixin(class_3218.class)
public abstract class ServerWorldMixin extends class_1937 implements IGameruleOverridesProvider {

    protected ServerWorldMixin(class_5269 properties, class_5321<class_1937> registryRef, class_5455 registryManager, class_6880<class_2874> dimensionEntry, boolean isClient, boolean debugWorld, long seed, int maxChainedNeighborUpdates) {
        super(properties, registryRef, registryManager, dimensionEntry, isClient, debugWorld, seed, maxChainedNeighborUpdates);
    }

    @Shadow public abstract class_26 getPersistentStateManager();

    @Unique private OverridesManager gamerulesOverrides;

    @SuppressWarnings("brittleShift")
    @Inject(
            method = "<init>",
            at = @At(
                    value = "INVOKE",
                    target = "Lnet/minecraft/world/PersistentStateManager;getOrCreate(Lnet/minecraft/world/PersistentStateType;)Lnet/minecraft/world/PersistentState;",
                    shift = At.Shift.AFTER
            )
    )
    private void unruled_initGamerulesOverridesManager(
            MinecraftServer server, Executor workerExecutor, class_32.class_5143 session,
            class_5268 properties, class_5321<class_1937> worldKey, class_5363 dimensionOptions,
            class_3949 worldGenerationProgressListener, boolean debugWorld, long seed,
            List<class_5304> spawners, boolean shouldTickTime, class_8565 random, CallbackInfo ci
    ) {
        this.gamerulesOverrides = this.getPersistentStateManager().method_17924(OverridesManager.getPersistentStateType());
    }

    @Inject(method="getGameRules", at = @At("HEAD"), cancellable = true)
    private void unruled_getGameRulesOverrides(CallbackInfoReturnable<class_1928> cir) {
        cir.setReturnValue(this.gamerulesOverrides.getOverrides());
    }

    @Override
    public OverridesManager unruled_getOverridesManager() {
        return this.gamerulesOverrides;
    }
}
